<?php
declare(strict_types=1);
namespace App\Controller;

use App\JsonRpc\NewsServiceInterface;
use App\Tools\PublicData;
use Hyperf\Di\Annotation\Inject;
use Hyperf\HttpServer\Annotation\AutoController;
use App\Tools\Result;
use Hyperf\Validation\Contract\ValidatorFactoryInterface;
use Hyperf\Context\Context;
use App\JsonRpc\UserServiceInterface;
use App\JsonRpc\WebsiteServiceInterface;
use Laminas\Mime\Decode;

/**
 * Class NewsController
 * @package App\Controller
 */
//#[AutoController]
class NewsController extends AbstractController
{
    #[Inject]
    protected ValidatorFactoryInterface $validationFactory;

    /**
     * @var NewsServiceInterface
     */
    #[Inject]
    private $newsServiceClient;
    /**
     * @var WebsiteServiceInterface
     */
    #[Inject]
    private $websiteServiceClient;

    /**
     * @var UserServiceInterface
     */
    #[Inject]
    private $userServiceClient;
    /**
     * @var WebsiteServiceInterface
     */
    #[Inject]
    private $WebsiteServiceClient;


    /**
     * 导航池列表
     * @return void
     */
    public function getCategoryList()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'page'=> 'required',
                'pageSize'=> 'required',
            ],
            [
                'page.required' => '第几页不能为空',
                'pageSize.required' => '每页显示条数不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
         //获取用户信息
        //  $user_id = Context::get("UserId");
        //  $userInfo = $this->userServiceClient->getUserInfo((int)$user_id);
        //  var_dump("用户信息：",$userInfo);
        //  $sszq = $userInfo['data']['sszq'];
        //  $type_id = $userInfo['data']['type_id']; //'1:个人会员 2：政务会员 3：企业会员 4:调研员 10000：管理员 20000：游客（小程序）'
        $result = $this->newsServiceClient->getCategoryList($requireData);
        if($result['data']){
            foreach ($result['data']['rows'] as $k=>$v) {
                $result['data']['rows'][$k]['pid_arr'] = $v['pid_arr']?json_decode($v['pid_arr']):[0];
            }
        }
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 站点下的导航池
     * @return void
     */
    public function categoryList()
    {

        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'pid'=> 'required'
            ],
            [
                'pid.required' => '父级ID不能为空'
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }

        $requireData['website_id'] = Context::get("SiteId");
         //获取用户信息
         $user_id = Context::get("UserId");
         $userInfo = $this->userServiceClient->getUserInfo((int)$user_id);
         var_dump("用户信息：",$userInfo);
         $sszq = $userInfo['data']['sszq'];
         $type_id = $userInfo['data']['type_id']; //'1:个人会员 2：政务会员 3：企业会员 4:调研员 10000：管理员 20000：游客（小程序）'
         //管理员看所有
         if($type_id == 10000){
             $result = $this->newsServiceClient->categoryList($requireData);
        } else {
            $requireData['sszq'] = $sszq;
            $result = $this->newsServiceClient->myCategoryList($requireData);
        }
//        $rep = PublicData::buildMenuTree($result['data']);
        return $result ? Result::success($result['data']) : Result::error($result['message']);
    }

    /**
     * 添加导航
     * @return array|void
     */
    public function addCategory()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'name'=> 'required',
                'seo_title'=> 'required',
                'seo_keywords'=> 'required',
                'seo_description'=> 'required',
            ],
            [
                'name.required' => '导航池名称不能为空',
                'seo_title.required' => 'seo标题名称不能为空',
                'seo_keywords.required' => 'seo关键词不能为空',
                'seo_description.required' => 'seo描述不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }

        $requireData['pid'] = isset($requireData['pid_arr'])?end($requireData['pid_arr']):'';
        $requireData['pid_arr'] = isset($requireData['pid_arr'])?json_encode($requireData['pid_arr']):'';

        $requireData['city_id'] = isset($requireData['city_arr_id'])?end($requireData['city_arr_id']):'';
        $requireData['city_arr_id'] = isset($requireData['city_arr_id'])?json_encode($requireData['city_arr_id']):'';

        $requireData['department_id'] = isset($requireData['department_arr_id'])?end($requireData['department_arr_id']):'';
        $requireData['department_arr_id'] = isset($requireData['department_arr_id'])?json_encode($requireData['department_arr_id']):'';

        $result = $this->newsServiceClient->addCategory($requireData);
        return $result ? Result::success($result['data']) : Result::error($result['message']);
    }

    /**
     * 更新导航池
     * @return array
     */
    public function updateCategory()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id'=>'required',
                'name'=> 'required',
                'seo_title'=> 'required',
                'seo_keywords'=> 'required',
                'seo_description'=> 'required',
            ],
            [
                'id.required' =>'ID不能为空',
                'name.required' => '栏目池名称不能为空',
                'seo_title.required' => 'seo标题名称不能为空',
                'seo_keywords.required' => 'seo关键词不能为空',
                'seo_description.required' => 'seo描述不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['pid'] = isset($requireData['pid_arr'])?end($requireData['pid_arr']):'';
        $requireData['pid_arr'] = isset($requireData['pid_arr'])?json_encode($requireData['pid_arr']):'';

        $requireData['city_id'] = isset($requireData['city_arr_id'])?end($requireData['city_arr_id']):'';
        $requireData['city_arr_id'] = isset($requireData['city_arr_id'])?json_encode($requireData['city_arr_id']):'';

        $requireData['department_id'] = isset($requireData['department_arr_id'])?end($requireData['department_arr_id']):'';
        $requireData['department_arr_id'] = isset($requireData['department_arr_id'])?json_encode($requireData['department_arr_id']):'';

        $result = $this->newsServiceClient->updateCategory($requireData);
        return $result['code']==200? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 删除分类
     * @return array
     */
    public function delCategory()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id'=> 'required',

            ],
            [
                'id.required' => 'id不能为空',

            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->delCategory($requireData);
        return $result['code']==200 ? Result::success($result['data']) : Result::error($result['message']);
    }

    /**
     * 资讯列表
     * @return void
     */
    public function getArticleList()
    {
        $requireData = $this->request->all();

        $validator = $this->validationFactory->make(
            $requireData,
            [
                'page'=> 'required',
                'pageSize'=> 'required',

            ],
            [
                'page.required' => 'id不能为空',
                'pageSize.required' => 'id不能为空',

            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['website_id'] = Context::get("SiteId");
        //获取用户信息
        $user_id = Context::get("UserId");
        $userInfo = $this->userServiceClient->getUserInfo((int)$user_id);
        var_dump("用户信息：",$userInfo);
        $sszq = $userInfo['data']['sszq'];
        //获取websiteid
        // $groupInfo = $this->WebsiteServiceClient->getWebsiteGroupInfo(['id' => $sszq]);
        // var_dump("groupInfo:",$groupInfo);
        // $sszqstr = implode(',',json_decode($groupInfo['data']['web_ids']));

        $type_id = $userInfo['data']['type_id']; //'1:个人会员 2：政务会员 3：企业会员 4:调研员 10000：管理员 20000：游客（小程序）'
        $requireData['type_id'] = $type_id;
        $requireData['user_id'] = $user_id;


        var_dump("资讯：",$requireData);
        $result = $this->newsServiceClient->getArticleList($requireData);
        //1通过，2待审核，3待发 4,拒绝 5删除
        $statusList = [
            '0'=>'待审核',
            '1'=>'已发布',
            '2'=>'待审核',
            '3'=>'待发',
            '4'=>'拒绝',
            '5'=>'删除',
        ];
        if($result['data']){
            foreach ($result['data']['rows'] as $k=>$v) {
                $result['data']['rows'][$k]['cat_arr_id'] = $v['cat_arr_id']?json_decode($v['cat_arr_id']):[0];
                $result['data']['rows'][$k]['tag'] = $v['tag']?json_decode($v['tag']):[];
                $result['data']['rows'][$k]['status_name'] = $statusList[$v['status']];
                $result['data']['rows'][$k]['level'] = (string)$v['level'];
                $result['data']['rows'][$k]['islink'] = isset($v['islink']) && $v['islink']>0?true:false;
            }
        }
        // $result = $this->newsServiceClient->getArticleList($requireData);

        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }

    /**
     * 获取导航池信息
     * @return void
     */
    public function getCategoryInfo()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id'=> 'required',

            ],
            [
                'id.required' => 'id不能为空',

            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->getCategoryInfo($requireData);
        return $result['code']==200 ? Result::success($result['data']) : Result::error($result['message']);
    }

    /**
     * 添加分类
     * @return array|void
     */
    public function addArticle()
    {
        // $a = ['asdlk1', '2342345234', [1, '222222222222']];
        // var_dump(json_encode($a));
        // return '222';
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'title'=> 'required',
                'cat_arr_id'=> 'required',
                'author'=> 'required',

            ],
            [
                'title.required' => '标题不能为空',
                'cat_arr_id.required' => '导航池ID不能为空',
                'author.required' => '作者不能为空',
            ]
        );
        if ($validator->fails()){
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['catid'] = isset($requireData['cat_arr_id'])?end($requireData['cat_arr_id']):'';
        $requireData['cat_arr_id'] = isset($requireData['cat_arr_id'])?json_encode($requireData['cat_arr_id']):'';

        $loginIp = $this->request->getHeader('x-forwarded-for')[0] ?? $this->request->getHeader('x-real-ip')[0] ?? $this->request->getServerParams()['remote_addr'] ?? '0.0.0.0';
        $requireData['ip'] = $loginIp;

//        $requireData['website_id'] = Context::get("SiteId");
        $requireData['admin_user_id'] =Context::get("UserId");
        
        $requireData['level'] = isset($requireData['level']) &&  $requireData['level']?$requireData['level']:0;
        $requireData['hits'] = isset($requireData['hits']) &&  $requireData['hits']?$requireData['hits']:0;
        $requireData['is_original'] = isset($requireData['is_original']) &&  $requireData['is_original']?$requireData['is_original']:0;
        $requireData['status'] = isset($requireData['status']) &&  $requireData['status']?$requireData['status']:0;
//        var_dump("入参：",$requireData);
        $result = $this->newsServiceClient->addArticle($requireData);

        return $result['code']==200 ? Result::success($result['data']) : Result::error($result['message']);
    }

    /**
     * 更新资讯
     * @return array
     */
    public function updateArticle()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id'=>'required',
                'title'=> 'required',
                'cat_arr_id'=> 'required',
                'author'=> 'required',
            ],
            [
                'title.required' => '标题不能为空',
                'cat_arr_id.required' => '导航池ID不能为空',
                'author.required' => '作者不能为空',
                'id.required' =>'ID不能为空'
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }

        $requireData['catid'] = isset($requireData['cat_arr_id'])?end($requireData['cat_arr_id']):'';
        $requireData['cat_arr_id'] = isset($requireData['cat_arr_id'])?json_encode($requireData['cat_arr_id']):'';

        $result = $this->newsServiceClient->updateArticle($requireData);
        return $result['code']==200? Result::success($result['data']) : Result::error($result['message']);
    }

    /**
     * 更新资讯状态
     * @return array
     */
    public function upArticleStatus()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id'=>'required',
                'status'=> 'required',
            ],
            [
                'id.required' => 'id不能为空',
                'status.required' => '状态不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->upArticleStatus($requireData);
        return $result['code']==200? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 删除分类
     * @return array
     */
    public function delArticle()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id'=> 'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }

//        $requireData['website_id'] = Context::get("SiteId");
        $result = $this->newsServiceClient->delArticle($requireData);
        return $result['code']==200 ? Result::success($result['data']) : Result::error($result['message']);
    }

    /**
     * 获取资讯信息
     * @return array
     */
    public function  getArticleInfo()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id'=> 'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }

        $result = $this->newsServiceClient->getArticleInfo($requireData);
        if($result['code']==0){
             return Result::error($result['message']);
        }
        $result['data']['cat_arr_id'] =  $result['data']['cat_arr_id']?json_decode($result['data']['cat_arr_id']):[];
        return $result['code']==200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 获取调查问卷列表
     * @return array
     */
    public function getSurveyList()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'page'=>'required',
                'pageSize'=>'required',
            ],
            [
                'page.required' => '第几页不能为空',
                'pageSize.required' => '每页显示条数不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->getSurveyList($requireData);
        return $result['code']==200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 获取调查问卷详情
     * @return array
     */
    public function getSurveyInfo()
    {
        $requireData = $this->request->all(); 
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'sur_id'=>'required'
            ], 
            [
               'sur_id.required' => 'sur_id不能为空', 
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage); 
        }
        $result = $this->newsServiceClient->getSurveyInfo($requireData);
        return $result['code']==200? Result::success($result['data']) : Result::error($result['message']);
    }    /**
     * 检测导航池名称是否存在
     * @return array
     */
    public function  checkCategoryName()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'name'=> 'required',
            ],
            [
                'name.required' => 'name不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }

        $result = $this->newsServiceClient->checkCategoryName($requireData);
        return $result['code']==200 ? Result::success($result['data']) : Result::error($result['message']);
    }

     //20250226  产品列表
     public function getGoodList(){
         $requireData = $this->request->all();
         $validator = $this->validationFactory->make(
             $requireData,
             [
                 'page'=> 'integer|required',
                 'page_size'=> 'integer|required',
             ],
             [
                 'page.integer' => 'page必须是整型',
                 'page_size.integer' => 'page_size必须是整型',
                 'page.required' => 'page不能为空',
                 'page_size.required' => 'page_size不能为空',
                
             ]
         );
         if ($validator->fails()) {
             $errorMessage = $validator->errors()->first();
             return Result::error($errorMessage);
         }
         $result = $this->newsServiceClient->getGoodList($requireData);
         return $result['code']==200 ? Result::success($result['data']) : Result::error($result['message']);
     }
     public function getGoodInfo(){
         $requireData = $this->request->all();
         $validator = $this->validationFactory->make(
             $requireData,
             [
                 'id'=> 'required',
             ],
             [
                 'id.required' => 'id不能为空',
             ]
         );
         if ($validator->fails()) {
             $errorMessage = $validator->errors()->first();
             return Result::error($errorMessage);
         }
         $result = $this->newsServiceClient->getGoodInfo($requireData);
         return $result['code']==200 ? Result::success($result['data']) : Result::error($result['message']);
         }
     public function updateGood(){
         $requireData = $this->request->all();
         $validator = $this->validationFactory->make(
            
             $requireData,
             [
                 'id'=> 'required',
             ], 
             [
                 'id.required' => 'id不能为空',
             ]
         );
         if ($validator->fails()) {
             $errorMessage = $validator->errors()->first();
             return Result::error($errorMessage);
         }
         $result = $this->newsServiceClient->updateGood($requireData);
         return $result['code']==200 ? Result::success($result['data']) : Result::error($result['message']
         );
         }
     public function addGood(){
         $requireData = $this->request->all();
         $validator = $this->validationFactory->make(
             $requireData,
             [
                 'name'=> 'required',
                //  'price'=> 'numeric',
                //  'min'=> 'numeric',
                //  'max'=> 'numeric',
                //  'hits  '=> 'numeric',
             ],
             [
                 'name.required' => '产品名称不能为空',
                //  'price.required' => '产品价格不能为空',
                //  'price.numeric' => '价格必须是数字',
                //  'min.numeric' => 'min必须是数字',
                //  'max.numeric' => 'max须是数字',
                //  'hits.numeric' => '点击量必须是数字',
          
             ]
         );
         if ($validator->fails()) {
             $errorMessage = $validator->errors()->first();
             return Result::error($errorMessage);
         }
         $result = $this->newsServiceClient->addGood($requireData);
         return $result['code']==200 ? Result::success($result['data']) : Result::error($result['message']);
         }
     public function delGood(){
         $requireData = $this->request->all();
         $validator = $this->validationFactory->make($requireData,
             [
                 'id'=> 'required',
             ],
             [
                 'id.required' => 'id不能为空',
             ]
         ); if ($validator->fails()) {
             $errorMessage = $validator->errors()->first();
             return Result::error($errorMessage);
         }
         $result = $this->newsServiceClient->delGood($requireData);
         return $result['code']==200 ? Result::success($result['data']) : Result::error($result['message']);
     }

      //20250226  产品列表

    //   20250306    招聘
      /*
      *后端-招聘 搜索及获取职位
      * @return array
      */
    public function getJobRecruitingList(){
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'page'=> 'integer|required',
                'page_size'=> 'integer|required',
            ],
            [
                'page.integer' => 'page必须是整型',
                'page_size.integer' => 'page_size必须是整型',
                'page.required' => 'page不能为空',
                'page_size.required' => 'page_size不能为空',
            ]   
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['website_id'] = Context::get("SiteId");
        $requireData['user_id'] = Context::get("UserId");
        // return Result::success($requireData);
        if (empty($requireData['website_id']) || empty($requireData['user_id'])){
            return Result::error('参数错误');
        }
        $result = $this->newsServiceClient->getJobRecruitingList($requireData);
        return $result['code']==200? Result::success($result['data']) : Result::error($result['message']);
    }
    /*
    *后端-招聘 获取职位详情
    * @return array
    */
    public function getJobRecruitingInfo(){
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id'=>'required|integer',
            ],
            [
                'id.required' => 'id不能为空',
                'id.integer' => 'id必须是整数',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();   
            return Result::error($errorMessage);
        }
        // return Result::success($requireData);
        $result = $this->newsServiceClient->getJobRecruitingInfo($requireData);
        return $result['code']==200? Result::success($result['data']) : Result::error($result['message']);
    }
    /*
    *后端-招聘 新增职位
    * @return array
    */
    public function addJobRecruiting(){
        $requireData = $this->request->all();
        // return Result::success($requireData);
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'title'=>'required',
                'cat_arr_id'=>'required',
                'city_arr_id'=>'required',
                'hy_id'=>'required|integer',
                'zw_id'=>'required|integer',
                'jtzw_id'=>'required|integer',
                'nature_id'=>'required|integer',
                'due_data'=>'required',
                'description'=>'required',
            ],   
            [
                'title.required' => '职位名称不能为空',
                'cat_arr_id.required' => '栏目不能为空',
                'city_arr_id.required' => '工作地区不能为空',
                'hy_id.required' => '行业分类不能为空',
                'hy_id.integer' => '行业分类必须是整数',
                'zw_id.required' => '职位分类不能为空',
                'zw_id.integer' => '职位分类必须是整数',
                'jtzw_id.required' => '职位不能为空',
                'jtzw_id.integer' => '职位分类必须是整数',
                'nature_id.required' => '职位性质不能为空',
                'nature_id.integer' => '职位性质必须是整数',
                'due_data.required' => '截止日期不能为空',
                'description.required' => '职位描述不能为空'
            ]
        ); 
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        if(isset($requireData['website_id']) && $requireData['website_id'] != null){
            $requireData['website_id'] = $requireData['website_id'];
        }else{
            $requireData['website_id'] = Context::get("SiteId");
        }
        // $requireData['website_id'] = Context::get("SiteId") ?? 0;
        $requireData['user_id'] = Context::get("UserId") ?? 0;
        $result = $this->newsServiceClient->addJobRecruiting($requireData);
        return $result['code']==200? Result::success($result['data']) : Result::error($result['message']);  
    }
    /*
    *后端-招聘 修改职位
    * @return array
    */
    public function upJobRecruiting(){
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id'=>'required|integer',
                'title'=>'required',
                'cat_arr_id'=>'required',
                'city_arr_id'=>'required',
                'hy_id'=>'required|integer',
                'zw_id'=>'required|integer',
                'jtzw_id'=>'required|integer',
                'nature_id'=>'required|integer',
                'due_data'=>'required',
                'description'=>'required',
            ],   
            [
                'id.required' => 'id不能为空',
                'id.integer' => 'id必须是整数',
                'title.required' => '职位名称不能为空',
                'cat_arr_id.required' => '栏目不能为空',
                'city_arr_id.required' => '工作地区不能为空',
                'hy_id.required' => '行业分类不能为空',
                'hy_id.integer' => '行业分类必须是整数',
                'zw_id.required' => '职位分类不能为空',
                'zw_id.integer' => '职位分类必须是整数',
                'jtzw_id.required' => '职位不能为空',
                'jtzw_id.integer' => '职位分类必须是整数',
                'nature_id.required' => '职位性质不能为空',
                'nature_id.integer' => '职位性质必须是整数',
                'due_data.required' => '截止日期不能为空',
                'description.required' => '职位描述不能为空'
            ]

        ); 
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        if(isset($requireData['website_id']) && $requireData['website_id'] != null){
            $requireData['website_id'] = $requireData['website_id'];
        }else{
            $requireData['website_id'] = Context::get("SiteId");
        }
        // $requireData['website_id'] = Context::get("SiteId") ?? 0;
        $requireData['user_id'] = Context::get("UserId") ?? 0;
        $result = $this->newsServiceClient->upJobRecruiting($requireData);
        return $result['code']==200? Result::success($result['data']) : Result::error($result['message']);  
    }
    /*
    *后端-招聘 删除职位
    * @return array
    */
    public function delJobRecruiting(){
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id'=>'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]   
        );
        $result = $this->newsServiceClient->delJobRecruiting($requireData);
        return $result['code']==200? Result::success($result['data']) : Result::error($result['message']);  
    }
    /*
    *后端-招聘 获取地区-省-市
    * @return array
    */
    public function getJobRecruitingArea(){
        $requireData = $this->request->all();        
        $result = $this->websiteServiceClient->selectWebsiteArea($requireData);
        return $result['code']==200? Result::success($result['data']) : Result::error($result['message']);   
    }
    /*
    *后端-招聘 行业分类
    * @return array
    */
    public function getIndustry(){
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id'=>'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]
        );
        $result = $this->newsServiceClient->getIndustry($requireData);
        return $result['code']==200? Result::success($result['data']) : Result::error($result['message']);   
    }
    /*
    *后端-招聘 职位分类
    * @return array
    */
    public function getPositionList(){
        $requireData = $this->request->all();
        $result = $this->newsServiceClient->getPositionList($requireData);
        return $result['code']==200? Result::success($result['data']) : Result::error($result['message']);    
    }
     /*
    *后端-招聘 职位性质
    * @return array
    */
    public function getJobNature(){
        $requireData = $this->request->all();
        $result = $this->newsServiceClient->getJobNature($requireData);
        return $result['code']==200? Result::success($result['data']) : Result::error($result['message']);    
    }
    /*
    *后端-招聘 工作经验
    * @return array
    */
    public function getExperience(){
        $requireData = $this->request->all();
        $result = $this->newsServiceClient->getExperience($requireData);
        return $result['code']==200? Result::success($result['data']) : Result::error($result['message']);
    }
    /*
    *后端-招聘 学历
    * @return array
    */
    public function getEducation(){
        $requireData = $this->request->all();
        $result = $this->newsServiceClient->getEducation($requireData);
        return $result['code']==200? Result::success($result['data']) : Result::error($result['message']);   
    }
    /*
    *后端-招聘 薪资
    * @return array
    */
    public function getSalary(){
        $requireData = $this->request->all();
        $result = $this->newsServiceClient->getSalary($requireData);
        return $result['code']==200? Result::success($result['data']) : Result::error($result['message']);   
    }
    /*
    *后端-招聘 语言
    * @return array
    */
    public function getLanguage(){
        $requireData = $this->request->all();
        $result = $this->newsServiceClient->getLanguage($requireData);
        return $result['code']==200? Result::success($result['data']) : Result::error($result['message']);   
    }
    /*
    *后端-招聘 语言-掌握能力
    * @return array
    */
    public function getLevel(){
        $requireData = $this->request->all();
        $result = $this->newsServiceClient->getLevel($requireData);
        return $result['code']==200? Result::success($result['data']) : Result::error($result['message']);   
    }
    /*
    *后端-招聘 公司规模
    * @return array
    */
    public function getCompanySize(){
        $requireData = $this->request->all();
        $result = $this->newsServiceClient->getCompanySize($requireData);
        return $result['code']==200? Result::success($result['data']) : Result::error($result['message']);
    }
    /*
    *后端-招聘 公司性质
    * @return array
    */
    public function getCompanyNature(){
        $requireData = $this->request->all();
        $result = $this->newsServiceClient->getCompanyNature($requireData);
        return $result['code']==200? Result::success($result['data']) : Result::error($result['message']);   
    }
}

